@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011, Carlos Garnacho <carlos@lanedo.com>
+ * Copyright (C) 2011, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,9 +15,14 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA  02110-1301, USA.
+ *
+ * Author: Carlos Garnacho <carlos@lanedo.com>
  */
 
+#include "config.h"
+
 #include <libtracker-sparql/tracker-sparql.h>
+
 #include "tracker-sparql-buffer.h"
 
 /* Maximum time (seconds) before forcing a sparql buffer flush */
@@ -296,6 +301,10 @@ tracker_sparql_buffer_update_array_cb (GObject      *object,
 			 */
 			error_pos += update_data->n_bulk_operations;
 			error = g_ptr_array_index (sparql_array_errors, error_pos);
+			if (error) {
+				g_critical ("  (Sparql buffer) Error in task %u of the array-update: %s",
+				            i, error->message);
+			}
 		}
 
 		/* Call finished handler with the error, if any */
