@@ -38,6 +38,7 @@
 #define GROUP_MONITORS                           "Monitors"
 #define GROUP_INDEXING                           "Indexing"
 #define GROUP_CRAWLING                           "Crawling"
+#define GROUP_WRITEBACK                          "Writeback"
 
 /* Default values */
 #define DEFAULT_VERBOSITY                        0
@@ -49,7 +50,9 @@
 #define DEFAULT_INDEX_ON_BATTERY                 FALSE
 #define DEFAULT_INDEX_ON_BATTERY_FIRST_TIME      TRUE
 #define DEFAULT_LOW_DISK_SPACE_LIMIT             1        /* 0->100 / -1 */
-#define DEFAULT_CRAWLING_INTERVAL                0        /* 0->365 / -1 */
+#define DEFAULT_CRAWLING_INTERVAL                -1       /* 0->365 / -1 / -2 */
+#define DEFAULT_REMOVABLE_DAYS_THRESHOLD         3        /* 1->365 / 0  */
+#define DEFAULT_ENABLE_WRITEBACK                 FALSE
 
 typedef struct {
 	/* General */
@@ -74,6 +77,10 @@ typedef struct {
 	GSList   *ignored_directories_with_content;
 	GSList   *ignored_files;
 	gint	  crawling_interval;
+	gint      removable_days_threshold;
+
+	/* Writeback */
+	gboolean  enable_writeback;
 
 	/* Convenience data */
 	GSList   *ignored_directory_patterns;
@@ -129,7 +136,12 @@ enum {
 	PROP_IGNORED_DIRECTORIES,
 	PROP_IGNORED_DIRECTORIES_WITH_CONTENT,
 	PROP_IGNORED_FILES,
-	PROP_CRAWLING_INTERVAL
+	PROP_CRAWLING_INTERVAL,
+	PROP_REMOVABLE_DAYS_THRESHOLD,
+
+	/* Writeback */
+	PROP_ENABLE_WRITEBACK
+
 };
 
 static ObjectToKeyFile conversions[] = {
@@ -150,7 +162,9 @@ static ObjectToKeyFile conversions[] = {
 	{ G_TYPE_POINTER, "ignored-directories",              GROUP_INDEXING, "IgnoredDirectories"        },
 	{ G_TYPE_POINTER, "ignored-directories-with-content", GROUP_INDEXING, "IgnoredDirectoriesWithContent" },
 	{ G_TYPE_POINTER, "ignored-files",                    GROUP_INDEXING, "IgnoredFiles"              },
-	{ G_TYPE_INT,	  "crawling-interval",		      GROUP_INDEXING, "CrawlingInterval"	  }
+	{ G_TYPE_INT,	  "crawling-interval",                GROUP_INDEXING, "CrawlingInterval"          },
+	{ G_TYPE_INT,	  "removable-days-threshold",         GROUP_INDEXING, "RemovableDaysThreshold"    },
+	{ G_TYPE_BOOLEAN, "enable-writeback",                 GROUP_WRITEBACK, "EnableWriteback"          },
 };
 
 G_DEFINE_TYPE (TrackerConfig, tracker_config, TRACKER_TYPE_CONFIG_FILE);
@@ -289,16 +303,38 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                       " List of files to NOT index (separator=;)",
 	                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (object_class,
-                                         PROP_CRAWLING_INTERVAL,
+	                                 PROP_CRAWLING_INTERVAL,
 	                                 g_param_spec_int ("crawling-interval",
 	                                                   "Crawling interval",
-                                                           " Interval in days to check the filesystem is up to date in the database."
-                                                           " If set to 0, crawling always occurs on startup, if -1 crawling is"
-                                                           " disabled entirely. Maximum is 365.",
-	                                                   -1,
+	                                                   " Interval in days to check the filesystem is up to date in the database,"
+	                                                   " maximum is 365, default is -1.\n"
+	                                                   "   -2 = crawling is disabled entirely\n"
+	                                                   "   -1 = crawling *may* occur on startup (if not cleanly shutdown)\n"
+	                                                   "    0 = crawling is forced",
+	                                                   -2,
 	                                                   365,
 	                                                   DEFAULT_CRAWLING_INTERVAL,
 	                                                   G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (object_class,
+	                                 PROP_REMOVABLE_DAYS_THRESHOLD,
+	                                 g_param_spec_int ("removable-days-threshold",
+	                                                   "Removable days threshold",
+	                                                   " Threshold in days after which files from removables devices"
+	                                                   " will be removed from database if not mounted. 0 means never, "
+	                                                   " maximum is 365.",
+	                                                   0,
+	                                                   365,
+	                                                   DEFAULT_REMOVABLE_DAYS_THRESHOLD,
+	                                                   G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
+	/* Writeback */
+	g_object_class_install_property (object_class,
+	                                 PROP_ENABLE_WRITEBACK,
+	                                 g_param_spec_boolean ("enable-writeback",
+	                                                       "Enable Writeback",
+	                                                       "Set to false to disable writeback",
+	                                                       DEFAULT_ENABLE_WRITEBACK,
+	                                                       G_PARAM_READWRITE));
 
 	g_type_class_add_private (object_class, sizeof (TrackerConfigPrivate));
 }
@@ -380,7 +416,16 @@ config_set_property (GObject      *object,
 		tracker_config_set_crawling_interval (TRACKER_CONFIG (object),
 		                                      g_value_get_int (value));
 		break;
+	case PROP_REMOVABLE_DAYS_THRESHOLD:
+		tracker_config_set_removable_days_threshold (TRACKER_CONFIG (object),
+		                                             g_value_get_int (value));
+		break;
 
+	/* Writeback */
+	case PROP_ENABLE_WRITEBACK:
+		tracker_config_set_enable_writeback (TRACKER_CONFIG (object),
+		                                     g_value_get_boolean (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -448,6 +493,14 @@ config_get_property (GObject    *object,
 	case PROP_CRAWLING_INTERVAL:
 		g_value_set_int (value, priv->crawling_interval);
 		break;
+	case PROP_REMOVABLE_DAYS_THRESHOLD:
+		g_value_set_int (value, priv->removable_days_threshold);
+		break;
+
+	/* Writeback */
+	case PROP_ENABLE_WRITEBACK:
+		g_value_set_boolean (value, priv->enable_writeback);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -805,9 +858,9 @@ config_load (TrackerConfig *config,
 
 	file = TRACKER_CONFIG_FILE (config);
 
-        if (use_defaults) {
-                config_create_with_defaults (config, file->key_file, FALSE);
-        }
+	if (use_defaults) {
+		config_create_with_defaults (config, file->key_file, FALSE);
+	}
 
 	if (!file->file_exists) {
 		tracker_config_file_save (file);
@@ -899,7 +952,7 @@ config_load (TrackerConfig *config,
 
 			if (!equal) {
 				g_object_set (config, conversions[i].property, new_dirs, NULL);
-                        }
+			}
 
 			g_slist_foreach (new_dirs, (GFunc) g_free, NULL);
 			g_slist_free (new_dirs);
@@ -1069,6 +1122,18 @@ tracker_config_get_enable_monitors (TrackerConfig *config)
 	return priv->enable_monitors;
 }
 
+gboolean
+tracker_config_get_enable_writeback (TrackerConfig *config)
+{
+	TrackerConfigPrivate *priv;
+
+	g_return_val_if_fail (TRACKER_IS_CONFIG (config), DEFAULT_ENABLE_WRITEBACK);
+
+	priv = TRACKER_CONFIG_GET_PRIVATE (config);
+
+	return priv->enable_writeback;
+}
+
 gint
 tracker_config_get_throttle (TrackerConfig *config)
 {
@@ -1237,6 +1302,18 @@ tracker_config_get_crawling_interval (TrackerConfig *config)
 	return priv->crawling_interval;
 }
 
+gint
+tracker_config_get_removable_days_threshold (TrackerConfig *config)
+{
+	TrackerConfigPrivate *priv;
+
+	g_return_val_if_fail (TRACKER_IS_CONFIG (config), 0);
+
+	priv = TRACKER_CONFIG_GET_PRIVATE (config);
+
+	return priv->removable_days_threshold;
+}
+
 void
 tracker_config_set_verbosity (TrackerConfig *config,
                               gint           value)
@@ -1287,6 +1364,20 @@ tracker_config_set_enable_monitors (TrackerConfig *config,
 	g_object_notify (G_OBJECT (config), "enable-monitors");
 }
 
+void
+tracker_config_set_enable_writeback (TrackerConfig *config,
+                                     gboolean       value)
+{
+	TrackerConfigPrivate *priv;
+
+	g_return_if_fail (TRACKER_IS_CONFIG (config));
+
+	priv = TRACKER_CONFIG_GET_PRIVATE (config);
+
+	priv->enable_writeback = value;
+	g_object_notify (G_OBJECT (config), "enable-writeback");
+}
+
 void
 tracker_config_set_throttle (TrackerConfig *config,
                              gint           value)
@@ -1393,8 +1484,8 @@ rebuild_filtered_lists (TrackerConfig *config)
 
 	if (priv->index_single_directories_unfiltered) {
 		priv->index_single_directories =
-		        tracker_path_list_filter_duplicates (priv->index_single_directories_unfiltered,
-		                                             ".", FALSE);
+			tracker_path_list_filter_duplicates (priv->index_single_directories_unfiltered,
+			                                     ".", FALSE);
 	}
 
 	if (!tracker_gslist_with_string_data_equal (old_list, priv->index_single_directories)) {
@@ -1429,7 +1520,7 @@ rebuild_filtered_lists (TrackerConfig *config)
 		new_list = g_slist_reverse (new_list);
 
 		priv->index_recursive_directories =
-		        tracker_path_list_filter_duplicates (new_list, ".", TRUE);
+			tracker_path_list_filter_duplicates (new_list, ".", TRUE);
 
 		g_slist_free (new_list);
 	}
@@ -1450,7 +1541,7 @@ tracker_config_set_index_recursive_directories (TrackerConfig *config,
 {
 	TrackerConfigPrivate *priv;
 	GSList *l;
-        gboolean equal;
+	gboolean equal;
 
 	g_return_if_fail (TRACKER_IS_CONFIG (config));
 
@@ -1458,7 +1549,7 @@ tracker_config_set_index_recursive_directories (TrackerConfig *config,
 
 	l = priv->index_recursive_directories_unfiltered;
 
-        equal = tracker_gslist_with_string_data_equal (roots, l);
+	equal = tracker_gslist_with_string_data_equal (roots, l);
 
 	if (!roots) {
 		priv->index_recursive_directories_unfiltered = NULL;
@@ -1470,11 +1561,11 @@ tracker_config_set_index_recursive_directories (TrackerConfig *config,
 	g_slist_foreach (l, (GFunc) g_free, NULL);
 	g_slist_free (l);
 
-        if (equal) {
-                return;
-        }
+	if (equal) {
+		return;
+	}
 
-        rebuild_filtered_lists (config);
+	rebuild_filtered_lists (config);
 }
 
 void
@@ -1483,7 +1574,7 @@ tracker_config_set_index_single_directories (TrackerConfig *config,
 {
 	TrackerConfigPrivate *priv;
 	GSList *l;
-        gboolean equal;
+	gboolean equal;
 
 	g_return_if_fail (TRACKER_IS_CONFIG (config));
 
@@ -1491,7 +1582,7 @@ tracker_config_set_index_single_directories (TrackerConfig *config,
 
 	l = priv->index_single_directories_unfiltered;
 
-        equal = tracker_gslist_with_string_data_equal (roots, l);
+	equal = tracker_gslist_with_string_data_equal (roots, l);
 
 	if (!roots) {
 		priv->index_single_directories_unfiltered = NULL;
@@ -1503,11 +1594,11 @@ tracker_config_set_index_single_directories (TrackerConfig *config,
 	g_slist_foreach (l, (GFunc) g_free, NULL);
 	g_slist_free (l);
 
-        if (equal) {
-                return;
-        }
+	if (equal) {
+		return;
+	}
 
-        rebuild_filtered_lists (config);
+	rebuild_filtered_lists (config);
 }
 
 void
@@ -1516,7 +1607,7 @@ tracker_config_set_ignored_directories (TrackerConfig *config,
 {
 	TrackerConfigPrivate *priv;
 	GSList *l;
-        gboolean equal;
+	gboolean equal;
 
 	g_return_if_fail (TRACKER_IS_CONFIG (config));
 
@@ -1524,7 +1615,7 @@ tracker_config_set_ignored_directories (TrackerConfig *config,
 
 	l = priv->ignored_directories;
 
-        equal = tracker_gslist_with_string_data_equal (roots, l);
+	equal = tracker_gslist_with_string_data_equal (roots, l);
 
 	if (!roots) {
 		priv->ignored_directories = NULL;
@@ -1536,9 +1627,9 @@ tracker_config_set_ignored_directories (TrackerConfig *config,
 	g_slist_foreach (l, (GFunc) g_free, NULL);
 	g_slist_free (l);
 
-        if (equal) {
-                return;
-        }
+	if (equal) {
+		return;
+	}
 
 	/* Re-set up the GPatternSpec list */
 	config_set_ignored_directory_conveniences (config);
@@ -1552,7 +1643,7 @@ tracker_config_set_ignored_directories_with_content (TrackerConfig *config,
 {
 	TrackerConfigPrivate *priv;
 	GSList *l;
-        gboolean equal;
+	gboolean equal;
 
 	g_return_if_fail (TRACKER_IS_CONFIG (config));
 
@@ -1560,7 +1651,7 @@ tracker_config_set_ignored_directories_with_content (TrackerConfig *config,
 
 	l = priv->ignored_directories_with_content;
 
-        equal = tracker_gslist_with_string_data_equal (roots, l);
+	equal = tracker_gslist_with_string_data_equal (roots, l);
 
 	if (!roots) {
 		priv->ignored_directories_with_content = NULL;
@@ -1572,9 +1663,9 @@ tracker_config_set_ignored_directories_with_content (TrackerConfig *config,
 	g_slist_foreach (l, (GFunc) g_free, NULL);
 	g_slist_free (l);
 
-        if (equal) {
-                return;
-        }
+	if (equal) {
+		return;
+	}
 
 	g_object_notify (G_OBJECT (config), "ignored-directories-with-content");
 }
@@ -1585,7 +1676,7 @@ tracker_config_set_ignored_files (TrackerConfig *config,
 {
 	TrackerConfigPrivate *priv;
 	GSList *l;
-        gboolean equal;
+	gboolean equal;
 
 	g_return_if_fail (TRACKER_IS_CONFIG (config));
 
@@ -1593,7 +1684,7 @@ tracker_config_set_ignored_files (TrackerConfig *config,
 
 	l = priv->ignored_files;
 
-        equal = tracker_gslist_with_string_data_equal (files, l);
+	equal = tracker_gslist_with_string_data_equal (files, l);
 
 	if (!files) {
 		priv->ignored_files = NULL;
@@ -1605,9 +1696,9 @@ tracker_config_set_ignored_files (TrackerConfig *config,
 	g_slist_foreach (l, (GFunc) g_free, NULL);
 	g_slist_free (l);
 
-        if (equal) {
-                return;
-        }
+	if (equal) {
+		return;
+	}
 
 	/* Re-set up the GPatternSpec list */
 	config_set_ignored_file_conveniences (config);
@@ -1633,6 +1724,24 @@ tracker_config_set_crawling_interval (TrackerConfig *config,
 	g_object_notify (G_OBJECT (config), "crawling-interval");
 }
 
+void
+tracker_config_set_removable_days_threshold (TrackerConfig *config,
+                                             gint           value)
+{
+	TrackerConfigPrivate *priv;
+
+	g_return_if_fail (TRACKER_IS_CONFIG (config));
+
+	if (!tracker_keyfile_object_validate_int (config, "removable-days-threshold", value)) {
+		return;
+	}
+
+	priv = TRACKER_CONFIG_GET_PRIVATE (config);
+
+	priv->removable_days_threshold = value;
+	g_object_notify (G_OBJECT (config), "removable-days-threshold");
+}
+
 /*
  * Convenience functions
  */
