@@ -283,6 +283,45 @@ get_uri_from_arg (const gchar *arg)
 	return uri;
 }
 
+static inline guint32
+get_uid_for_pid (const gchar  *pid_as_string,
+                 gchar       **filename)
+{
+	GFile *f;
+	GFileInfo *info;
+	GError *error = NULL;
+	gchar *fn;
+	guint uid;
+
+	fn = g_build_filename ("/proc", pid_as_string, "cmdline", NULL);
+
+	f = g_file_new_for_path (fn);
+	info = g_file_query_info (f,
+	                          G_FILE_ATTRIBUTE_UNIX_UID,
+	                          G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+	                          NULL,
+	                          &error);
+
+	if (error) {
+		g_warning ("Could not stat() file:'%s', %s", fn, error->message);
+		g_error_free (error);
+		uid = 0;
+	} else {
+		uid = g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_UID);
+	}
+
+	if (filename) {
+		*filename = fn;
+	} else {
+		g_free (fn);
+	}
+
+	g_object_unref (info);
+	g_object_unref (f);
+
+	return uid;
+}
+
 void
 tracker_control_general_run_default (void)
 {
@@ -331,6 +370,10 @@ tracker_control_general_run (void)
 	if (kill_option != TERM_NONE ||
 	    terminate_option != TERM_NONE ||
 	    list_processes) {
+		guint32 own_pid;
+		guint32 own_uid;
+		gchar *own_uid_str;
+
 		pids = get_pids ();
 		str = g_strdup_printf (g_dngettext (NULL,
 		                                    "Found %d PID…",
@@ -340,12 +383,27 @@ tracker_control_general_run (void)
 		g_print ("%s\n", str);
 		g_free (str);
 
+		/* Establish own uid/pid */
+		own_pid = (guint32) getpid ();
+		own_uid_str = g_strdup_printf ("%d", own_pid);
+		own_uid = get_uid_for_pid (own_uid_str, NULL);
+		g_free (own_uid_str);
+
 		for (l = pids; l; l = l->next) {
+			GError *error = NULL;
 			gchar *filename;
 			gchar *contents = NULL;
 			gchar **strv;
+			guint uid;
 
-			filename = g_build_filename ("/proc", l->data, "cmdline", NULL);
+			uid = get_uid_for_pid (l->data, &filename);
+
+			/* Stat the file and make sure current user == file owner */
+			if (uid != own_uid) {
+				continue;
+			}
+
+			/* Get contents to determin basename */
 			if (!g_file_get_contents (filename, &contents, NULL, &error)) {
 				str = g_strdup_printf (_("Could not open '%s'"), filename);
 				g_printerr ("%s, %s\n",
@@ -442,12 +500,12 @@ tracker_control_general_run (void)
 
 	if (hard_reset || soft_reset) {
 		guint log_handler_id;
+#ifndef DISABLE_JOURNAL
 		const gchar *rotate_to = NULL;
 		TrackerDBConfig *db_config;
 		gsize chunk_size;
 		gint chunk_size_mb;
-
-		db_config = tracker_db_config_new ();
+#endif /* DISABLE_JOURNAL */
 
 		/* Set log handler for library messages */
 		log_handler_id = g_log_set_handler (NULL,
@@ -457,6 +515,9 @@ tracker_control_general_run (void)
 
 		g_log_set_default_handler (log_handler, NULL);
 
+#ifndef DISABLE_JOURNAL
+		db_config = tracker_db_config_new ();
+
 		chunk_size_mb = tracker_db_config_get_journal_chunk_size (db_config);
 		chunk_size = (gsize) ((gsize) chunk_size_mb * (gsize) 1024 * (gsize) 1024);
 		rotate_to = tracker_db_config_get_journal_rotate_destination (db_config);
@@ -467,10 +528,13 @@ tracker_control_general_run (void)
 
 		g_object_unref (db_config);
 
+#endif /* DISABLE_JOURNAL */
+
 		/* Clean up (select_cache_size and update_cache_size don't matter here) */
 		if (!tracker_db_manager_init (TRACKER_DB_MANAGER_REMOVE_ALL,
 		                              NULL,
 		                              FALSE,
+		                              FALSE,
 		                              100,
 		                              100,
 		                              NULL,
@@ -483,12 +547,15 @@ tracker_control_general_run (void)
 
 			return EXIT_FAILURE;
 		}
-
+#ifndef DISABLE_JOURNAL
 		tracker_db_journal_init (NULL, FALSE, NULL);
+#endif /* DISABLE_JOURNAL */
 
 		tracker_db_manager_remove_all (hard_reset);
 		tracker_db_manager_shutdown ();
+#ifndef DISABLE_JOURNAL
 		tracker_db_journal_shutdown (NULL);
+#endif /* DISABLE_JOURNAL */
 
 		/* Unset log handler */
 		g_log_remove_handler (NULL, log_handler_id);
