@@ -19,9 +19,21 @@
 
 #include "config.h"
 
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
+#include <errno.h>
+#include <fcntl.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <sys/mman.h>
 
 #include <glib.h>
+#include <glib/gstdio.h>
+
 #include <gio/gio.h>
 
 #include <libtracker-extract/tracker-extract.h>
@@ -45,10 +57,9 @@ static gchar *
 get_file_content (const gchar  *uri,
                   gsize         n_bytes)
 {
-	GFile *file;
-	GFileInputStream  *stream;
-	GError     *error = NULL;
-	gchar      *text;
+	GError *error = NULL;
+	gchar *text, *path;
+	int fd;
 
 	/* If no content requested, return */
 	if (n_bytes == 0) {
@@ -56,15 +67,19 @@ get_file_content (const gchar  *uri,
 	}
 
 	/* Get filename from URI */
-	file = g_file_new_for_uri (uri);
-	stream = g_file_read (file, NULL, &error);
-	if (error) {
-		g_message ("Could not read file '%s': %s",
+	path = g_filename_from_uri (uri, NULL, NULL);
+
+	fd = g_open (path, O_RDONLY | O_NOATIME, 0);
+	if (fd == -1 && errno == EPERM) {
+		fd = g_open (path, O_RDONLY, 0);
+	}
+
+	if (fd == -1) {
+		g_message ("Could not open file '%s': %s",
 		           uri,
 		           error->message);
 		g_error_free (error);
-		g_object_unref (file);
-
+		g_free (path);
 		return NULL;
 	}
 
@@ -72,12 +87,12 @@ get_file_content (const gchar  *uri,
 	         uri, n_bytes);
 
 	/* Read up to n_bytes from stream. Output is always, always valid UTF-8 */
-	text = tracker_read_text_from_stream (G_INPUT_STREAM (stream),
-	                                      n_bytes,
-	                                      TRY_LOCALE_TO_UTF8_CONVERSION);
+	text = tracker_read_text_from_fd (fd,
+	                                  n_bytes,
+	                                  TRY_LOCALE_TO_UTF8_CONVERSION);
 
-	g_object_unref (stream);
-	g_object_unref (file);
+	close (fd);
+	g_free (path);
 
 	return text;
 }
